.. _pulsar-advantage:

Pulsar Advantage
========================


Python 3
--------------------
Pulsar was written using python 3.2 and backported to python 2.7 and python 2.6.
It is now developed in python 3.3 while keeping backward compatibility.


Flexibility
-------------------
Pulsar's codebase is small, at about 10,000 lines of code. The source code is
open and it has a very liberal license. This way you know you'll never be in a position where
you can't add a feature you need.